const chai = require("chai");

const expect = chai.expect;
const Parser = require("../index");

describe ("Parser", () => {
    describe ("#constructor", () => {
        let parser;

        beforeEach( () => {
            parser = new Parser("test string");
        });
        
        it("constructs new Parser", () => {
            expect(parser).to.be.an.instanceOf(Parser);
        });
        
        it("should set testString to pram", () => {
            expect(parser.testString).to.equal("test string");
        });

        it("should set parsedString to null", () => {
            expect(parser.parsedString).to.be.null;
        });
    });
    
    describe ("#parse", () => {
        let parser;
        
        beforeEach( () => {
            parser = new Parser();
        });
       
        it("should be valid: (eyJ0ZXN0IjoiY2FzZSJ9)", () => {
            expect(parser.parse("eyJ0ZXN0IjoiY2FzZSJ9")).to.be.true;
        });

        it("should be valid: ({\"test\":\"case\"})", () => {
            expect(parser.parse("{\"test\":\"case\"}")).to.be.true;
        });

        it("should be invalid: (dHJhc2ggZGF0YQ==)", () => {
            expect(parser.parse("dHJhc2ggZGF0YQ==")).to.be.false;
        });

        it("should be invalid: (invalid json)", () => {
            expect(parser.parse("invalid json")).to.be.false;
        });

        it("should set parsedString to null if invalid JSON", () => {
            parser.parse("invalid json");
            expect(parser.parsedString).to.be.null;
        });

        it("should set parsedString to JSON object if valid JSON", () => {
            let ret = parser.parse("{\"test\":\"case\"}");
            expect (ret).to.be.true;
            expect(parser.parsedString).to.be.an("Object");
            expect(parser.parsedString.test).to.equal("case");
        });
    });
});
